# Advent of Code CLI

[![PyPI version](https://img.shields.io/pypi/v/aocli)](https://pypi.org/project/aocli/)
[![Supported Python Versions](https://img.shields.io/pypi/pyversions/aocli)](https://pypi.org/project/aocli/)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/sgraaf/aocli/main.svg)](https://results.pre-commit.ci/latest/github/sgraaf/aocli/main)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

> This repository contains a CLI and various utility functions for Advent of Code puzzles
